pub struct DOMAIN_SEPARATORCall;Expand description
@dev Returns the domain separator used in the encoding of the signature for {permit},
as defined by {EIP712}.
Function with signature DOMAIN_SEPARATOR() and selector 0x3644e515.
function DOMAIN_SEPARATOR() external view returns (bytes32);Trait Implementations
Sourceimpl Clone for DOMAIN_SEPARATORCall
impl Clone for DOMAIN_SEPARATORCall
Sourcefn clone(&self) -> DOMAIN_SEPARATORCall
fn clone(&self) -> DOMAIN_SEPARATORCall
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl SolCall for DOMAIN_SEPARATORCall
impl SolCall for DOMAIN_SEPARATORCall
Sourcetype Parameters<'a> = ()
type Parameters<'a> = ()
The underlying tuple type which represents this type’s arguments. Read more
Sourcetype Token<'a> = <<DOMAIN_SEPARATORCall as SolCall>::Parameters<'a> as SolType>::Token<'a>
type Token<'a> = <<DOMAIN_SEPARATORCall as SolCall>::Parameters<'a> as SolType>::Token<'a>
The arguments’ corresponding [TokenSeq] type.
Sourcetype ReturnTuple<'a> = (FixedBytes<32>,)
type ReturnTuple<'a> = (FixedBytes<32>,)
The underlying tuple type which represents this type’s return values. Read more
Sourcetype ReturnToken<'a> = <<DOMAIN_SEPARATORCall as SolCall>::ReturnTuple<'a> as SolType>::Token<'a>
type ReturnToken<'a> = <<DOMAIN_SEPARATORCall as SolCall>::ReturnTuple<'a> as SolType>::Token<'a>
The returns’ corresponding [TokenSeq] type.
Sourcefn new<'a>(tuple: <Self::Parameters<'a> as SolType>::RustType) -> Self
fn new<'a>(tuple: <Self::Parameters<'a> as SolType>::RustType) -> Self
Convert from the tuple type used for ABI encoding and decoding.
Sourcefn tokenize_returns(ret: &Self::Return) -> Self::ReturnToken<'_>
fn tokenize_returns(ret: &Self::Return) -> Self::ReturnToken<'_>
Tokenize the call’s return values.
Sourcefn abi_decode_returns(data: &[u8]) -> Result<Self::Return>
fn abi_decode_returns(data: &[u8]) -> Result<Self::Return>
ABI decode this call’s return values from the given slice.
Sourcefn abi_decode_returns_validate(data: &[u8]) -> Result<Self::Return>
fn abi_decode_returns_validate(data: &[u8]) -> Result<Self::Return>
ABI decode this call’s return values from the given slice, with validation. Read more
fn abi_encoded_size(&self) -> usize
fn abi_encoded_size(&self) -> usize
The size of the encoded data in bytes, without its selector.
fn abi_decode_raw(data: &[u8]) -> Result<Self, Error>
fn abi_decode_raw(data: &[u8]) -> Result<Self, Error>
ABI decode this call’s arguments from the given slice, without its
selector.
fn abi_decode_raw_validate(data: &[u8]) -> Result<Self, Error>
fn abi_decode_raw_validate(data: &[u8]) -> Result<Self, Error>
ABI decode this call’s arguments from the given slice, without its
selector, with validation. Read more
fn abi_decode(data: &[u8]) -> Result<Self, Error>
fn abi_decode(data: &[u8]) -> Result<Self, Error>
ABI decode this call’s arguments from the given slice, with the
selector.
fn abi_decode_validate(data: &[u8]) -> Result<Self, Error>
fn abi_decode_validate(data: &[u8]) -> Result<Self, Error>
ABI decode this call’s arguments from the given slice, with the
selector, with validation. Read more
fn abi_encode_raw(&self, out: &mut Vec<u8>)
fn abi_encode_raw(&self, out: &mut Vec<u8>)
ABI encode the call to the given buffer without its selector.
fn abi_encode(&self) -> Vec<u8> ⓘ
fn abi_encode(&self) -> Vec<u8> ⓘ
ABI encode the call to the given buffer with its selector.
fn abi_encode_returns(ret: &Self::Return) -> Vec<u8> ⓘ
fn abi_encode_returns(ret: &Self::Return) -> Vec<u8> ⓘ
ABI encode the call’s return value.