pub struct DOMAIN_SEPARATORReturn {
pub _0: FixedBytes<32>,
}Expand description
@dev Returns the domain separator used in the encoding of the signature for {permit},
as defined by {EIP712}.
Container type for the return parameters of the DOMAIN_SEPARATOR() function.
Fields
_0: FixedBytes<32>Trait Implementations
Sourceimpl Clone for DOMAIN_SEPARATORReturn
impl Clone for DOMAIN_SEPARATORReturn
Sourcefn clone(&self) -> DOMAIN_SEPARATORReturn
fn clone(&self) -> DOMAIN_SEPARATORReturn
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreAuto Trait Implementations
impl Freeze for DOMAIN_SEPARATORReturn
impl RefUnwindSafe for DOMAIN_SEPARATORReturn
impl Send for DOMAIN_SEPARATORReturn
impl Sync for DOMAIN_SEPARATORReturn
impl Unpin for DOMAIN_SEPARATORReturn
impl UnwindSafe for DOMAIN_SEPARATORReturn