pub struct permitReturn {}Expand description
@dev Sets value as the allowance of spender over owner’s tokens,
given owner’s signed approval.
IMPORTANT: The same issues {IERC20-approve} has related to transaction ordering also apply here.
Emits an {Approval} event.
Requirements:
spendercannot be the zero address.deadlinemust be a timestamp in the future.v,randsmust be a validsecp256k1signature fromownerover the EIP712-formatted function arguments.- the signature must use
owner’s current nonce (see {nonces}).
For more information on the signature format, see the
https://eips.ethereum.org/EIPS/eip-2612#specification[relevant EIP section].
Container type for the return parameters of the permit(address,address,uint256,uint256,uint8,bytes32,bytes32) function.